#ifndef  MODULES_STRINGS_H
#define  MODULES_STRINGS_H

/*
**   strings.h
**
**   (C) Copyright 1998-2003 Rocklyte Systems.
**       All Rights Reserved.
*/

#ifndef  MAIN_H
#include <pandora/main.h>
#endif

#include <pandora/misc/time.h>

#define MODVERSION_STRINGS ((FLOAT)1.0)

#define SBF_NODUPLICATES 0x00000001
#define SBF_SORT         0x00000002
#define SBF_CASE         0x00000004
#define SBF_DESC         0x00000008

#define STF_KEEPINTEGRITY 0x00000001
#define STF_IGNOREQUOTES  0x00000002

#define STR_NUMBER 1
#define STR_FLOAT  2
#define STR_STRING 3

#define COPY_ALL         0x7fffffff

#ifndef LOCAL_STRINGS

struct StringsBase {
   LONG   (*IntToStr)(LARGE, STRING, LONG);
   LONG   (*StrShrink)(STRING, LONG, LONG);
   LONG   (*StrExpand)(STRING, LONG, LONG);
   ERROR  (*StrInsert)(STRING, STRING, LONG, LONG, LONG);
   LONG   (*StrSearch)(STRING, STRING, LONG);
   void   (*StrUpper)(STRING);
   void   (*StrLower)(STRING);
   void   (*StrCapitalise)(STRING);
   LONG   (*StrLineLength)(STRING);
   STRING (*StrNextLine)(STRING);
   ERROR  (*StrReplace)(STRING, STRING, STRING, STRING *, LONG);
   ERROR  (*StrTranslate)(STRING, LONG, LONG);
   ERROR  (*StrCalculate)(STRING, DOUBLE *, STRING, LONG);
   LONG   (*FloatToStr)(DOUBLE, STRING, LONG);
   DOUBLE (*StrToFloat)(STRING);
   LONG   (*StrCopy)(STRING, STRING, LONG);
   STRING (*StrClone)(STRING);
   LONG   (*StrLength)(STRING);
   LARGE  (*StrToInt)(STRING);
   ERROR  (*StrSort)(STRING *, LONG);
   STRING * (*StrBuildArray)(STRING, LONG, LONG, LONG);
   LONG   (*UTF8CharacterOffset)(STRING, LONG);
   LONG   (*UTF8Length)(STRING);
   LONG   (*UTF8OffsetToCharacter)(STRING, LONG);
   LONG   (*UTF8PrevLength)(STRING, LONG);
   LONG   (*UTF8CharacterLength)(STRING);
   LONG   (*UTF8ReadValue)(STRING, LONG *);
   LONG   (*UTF8WriteValue)(LONG, STRING, LONG);
   ERROR  (*StrFormatTags)(STRING, LONG, STRING, ...);
   ERROR  (*StrFormatDate)(STRING, LONG, STRING, struct Time *);
   ERROR  (*StrReadColour)(STRING, LONG *, LONG *, LONG *, LONG *);
   LONG   (*StrDatatype)(STRING);
   LONG   (*CharCopy)(STRING, STRING, LONG);
};

#define CharCopy(a,b,c)            (StringsBase->CharCopy(a,b,c))
#define FloatToStr(a,b,c)          (StringsBase->FloatToStr(a,b,c))
#define IntToStr(a,b,c)            (StringsBase->IntToStr(a,b,c))
#define StrBuildArray(a,b,c,d)     (StringsBase->StrBuildArray(a,b,c,d))
#define StrCalculate(a,b,c,d)      (StringsBase->StrCalculate(a,b,c,d))
#define StrCapitalise(a)           (StringsBase->StrCapitalise(a))
#define StrClone(a)                (StringsBase->StrClone(a))
#define StrCopy(a,b,c)             (StringsBase->StrCopy(a,b,c))
#define StrDatatype(a)             (StringsBase->StrDatatype(a))
#define StrExpand(a,b,c)           (StringsBase->StrExpand(a,b,c))
#define StrFormat                  (StringsBase->StrFormatTags)
#define StrFormatDate(a,b,c,d)     (StringsBase->StrFormatDate(a,b,c,d))
#define StrInsert(a,b,c,d,e)       (StringsBase->StrInsert(a,b,c,d,e))
#define StrLength(a)               (StringsBase->StrLength(a))
#define StrLineLength(a)           (StringsBase->StrLineLength(a))
#define StrLower(a)                (StringsBase->StrLower(a))
#define StrNextLine(a)             (StringsBase->StrNextLine(a))
#define StrReadColour(a,b,c,d,e)   (StringsBase->StrReadColour(a,b,c,d,e))
#define StrReplace(a,b,c,d,e)      (StringsBase->StrReplace(a,b,c,d,e))
#define StrSearch(a,b,c)           (StringsBase->StrSearch(a,b,c))
#define StrShrink(a,b,c)           (StringsBase->StrShrink(a,b,c))
#define StrSort(a,b)               (StringsBase->StrSort(a,b))
#define StrToFloat(a)              (StringsBase->StrToFloat(a))
#define StrToInt(a)                (StringsBase->StrToInt(a))
#define StrTranslate(a,b,c)        (StringsBase->StrTranslate(a,b,c))
#define StrUpper(a)                (StringsBase->StrUpper(a))
#define UTF8CharacterLength(a)     (StringsBase->UTF8CharacterLength(a))
#define UTF8CharacterOffset(a,b)   (StringsBase->UTF8CharacterOffset(a,b))
#define UTF8Length(a)              (StringsBase->UTF8Length(a))
#define UTF8OffsetToCharacter(a,b) (StringsBase->UTF8OffsetToCharacter(a,b))
#define UTF8PrevLength(a,b)        (StringsBase->UTF8PrevLength(a,b))
#define UTF8ReadValue(a,b)         (StringsBase->UTF8ReadValue(a,b))
#define UTF8WriteValue(a,b,c)      (StringsBase->UTF8WriteValue(a,b,c))

#endif /* LOCAL_STRINGS */

#endif /* MODULES_STRINGS_H */
